## File "Configs/kupu.py"
## -*- coding: utf-8 -*-
# 
# Configuration of kupu visual editor.



##---------------------------------------------------------------------------



## KUPU_CONFIGURATION
# Kupu editor settings.
# Edit this dictionnary to modify your kupu visual editor configuration.
# 
# 
#  * 'linkbyuid' (required) : boolean
#    Create link using UIDs.
#    Links to objects on this site created by Kupu can use unique object ids so
#    that the links remain valid even if the target object is renamed or moved
#    elsewhere on the site.
# 
#  * 'table_classnames' (required) : list
#    list of class names to be made available in the table drawer
# 
#  * 'html_exclusions' (required) : list
#    HTML tags and attributes to be removed when saving documents.
# 
#  * 'style_whitelist' (required) : list
#    List of style elements to be permitted (one per line).
# 
#  * 'class_blacklist' (required) : list
#    List of classnames to be excluded (one per line).
# 
#  * 'installBeforeUnload' (optional - default : None) : boolean
#    Install Kupu code to detect form changes
# 
#  * 'parastyles' (optional - default : None) : list
#    List of paragraph styles to appear in the style pulldown.
#    Format is title|tag or title|tag|className, one per line.
# 
# 
# See configure_kupu() arguments in kupu/plone/plonelibrarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_CONFIGURATION = {
  'linkbyuid' : True,

  'table_classnames' : [
                        'plain',
                        'listing',
                        'vertical listing',
                        'listing nosort|unsorted listing',
                        'ArcTableSyle1|Arc de seine',
                      ],

  'html_exclusions' : [
                {
                  'tags' : ('center', 'span', 'tt', 'big', 'small', 's', 'basefont', 'font'),
                  'attributes' : (),
                  'keep': True,
                },
                {
                  'tags' : (),
                  'attributes' : ('dir','lang','valign','halign','border','frame','rules','cellspacing','cellpadding','bgcolor'),
                  'keep': True,
                },
                {
                  'tags' : ('table','th','td'),
                  'attributes' : ('width','height'),
                  'keep': True,
                },
                {
                  'tags' : '',
                  'attributes' : '',
                  'keep': True,
                }
              ],

  'style_whitelist' : ['text-align', 'list-style-type', 'float',],

  'class_blacklist' : [],

  'installBeforeUnload' : True,

  'parastyles' : [
                    'Titre 1|h1|titre1',
                    'Titre 2|h2|titre2',
                    'Titre 3|h3|titre3',
                 ],
}



##---------------------------------------------------------------------------



## KUPU_DELETED_LIBRARIES
# Delete existing kupu libraries.
# Modify this tuple of strings to delete existing kupu libraries.
# 
# 
# See deleteLibraries() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_DELETED_LIBRARIES = ()



##---------------------------------------------------------------------------



## KUPU_CREATED_LIBRARIES
# Create new kupu libraries.
# Modify this tuple of dictionnaries to create new kupu libraries.
# 
# 
# * 'id' (required) : string
#   Id of the created library.
# 
# * 'title' (required) : tal expression
#   Title of the created library.
# 
# * 'uri' (required) : tal expression / string
#   URI of the created library
# 
# * 'src' (required) : tal expression / string
#   Source URI of the created library
# 
# * 'icon' (required) : tal expression / string
#   Icon URI of the created library
# 
# 
# See addLibrary() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_CREATED_LIBRARIES = (
  {
    'id' : 'images',
    'title' : 'Images',
    'uri' : 'string:${portal_url}/images',
    'src' : 'string:${portal_url}/images/kupucollection.xml',
    'icon' : 'string:${portal_url}/folder_icon.gif',
  },
)



##---------------------------------------------------------------------------



## KUPU_UPDATED_LIBRARIES
# Existing Kupu libraries update configuration.
# Modify this tuple of dictionnary to update existing kupu libraries.
# 
# 
# * 'id' (required) : string
#   Id of the updated library.
# 
# * 'new_id' (optional) : string
#   New id of the updated library.
# 
# * 'title' (optional) : tal expression
#   Title of the updated library.
# 
# * 'uri' (optional) : tal expression / string
#   URI of the updated library
# 
# * 'src' (optional) : tal expression / string
#   Source URI of the updated library
# 
# * 'icon' (optional) : tal expression / string
#   Icon URI of the updated library
# 
# 
# See updateLibraries() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_UPDATED_LIBRARIES = ()




##---------------------------------------------------------------------------



## KUPU_DELETED_RESOURCES
# Delete existing kupu resources.
# Modify this tuple of strings to delete existing kupu ressources.
# 
# 
# See deleteResourceTypes() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_DELETED_RESOURCES = ()



##---------------------------------------------------------------------------



## KUPU_CREATED_RESOURCES
# Create new kupu resources.
# Modify this tuple of dictionnaries to create new kupu ressources.
# 
# 
# * 'resource_type' (required) : string
#   Name of the created resource.
# 
# * 'portal_types' (required) : list
#   List of portal types names to be used by this resource.
# 
# 
# See addResourceType() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_CREATED_RESOURCES = (
)



##---------------------------------------------------------------------------



## KUPU_UPDATED_RESOURCES
# Existing Kupu resources update configuration.
# Modify this tuple of dictionnary to update existing kupu ressources.
# 
# 
# * 'resource_type' (required) : string
#   New name of the updated resource.
# 
# * 'old_type' (required) : string
#   Current name of the updated resource.
# 
# * 'portal_types' (required) : list
#   List of portal types names to be used by this resource.
# 
# See updateResourceTypes() arguments in kupu/plone/librarytool.py
# for the latest list of all available keys and default values.
# 
# 
KUPU_UPDATED_RESOURCES = (
  {
    'resource_type' : 'collection',
    'old_type' : 'collection',
    'portal_types' :  ('Plone Site', 'Folder', 'Large Plone Folder'),
  },
  {
    'resource_type' : 'mediaobject',
    'old_type' : 'mediaobject',
    'portal_types' : ('Image',),
  },
  {
    'resource_type' : 'linkable',
    'old_type' : 'linkable',
    'portal_types' : ('PloneArticle', 'File', 'Image', 'Questionnaire', 'Newsletter', 'Document', 'News Item', 'Event',),
  }
)



