## File "PloneInstaller/Scripts/kupu_setup.py"
## -*- coding: utf-8 -*-
# 
# This file use the configuration described in "Configs/kupu.py" to setup the kupu visual editor.



from Products.CMFCore.utils import getToolByName



#########################################################################################################
########################################## Public methods ###############################################
#########################################################################################################



def kupu_install(self, out, project_name, globals):
    try:
      kupu_module = __import__("Configs.kupu",
                                globals, locals(),
                                [
                                  'KUPU_CONFIGURATION',
                                  'KUPU_DELETED_LIBRARIES',
                                  'KUPU_CREATED_LIBRARIES',
                                  'KUPU_UPDATED_LIBRARIES',
                                  'KUPU_DELETED_RESOURCES',
                                  'KUPU_CREATED_RESOURCES',
                                  'KUPU_UPDATED_RESOURCES',
                                ]
                              )

      out.openSection("Configs.kupu setup")

      # Kupu configuration
      kupu_configuration = getattr(kupu_module, 'KUPU_CONFIGURATION', None)
      if kupu_configuration != None:
        _installKupuConfiguration(self, out, kupu_configuration)


      # Kupu deleted libraries
      kupu_deleted_libraries = getattr(kupu_module, 'KUPU_DELETED_LIBRARIES', None)
      if kupu_deleted_libraries != None:
        _installKupuDeletedLibraries(self, out, kupu_deleted_libraries)

      # Kupu created libraries
      kupu_created_libraries = getattr(kupu_module, 'KUPU_CREATED_LIBRARIES', None)
      if kupu_created_libraries != None:
        _installKupuCreatedLibraries(self, out, kupu_created_libraries)

      # Kupu updated libraries
      kupu_updated_libraries = getattr(kupu_module, 'KUPU_UPDATED_LIBRARIES', None)
      if kupu_updated_libraries != None:
        _installKupuUpdatedLibraries(self, out, kupu_updated_libraries)


      # Kupu deleted resources
      kupu_deleted_resources = getattr(kupu_module, 'KUPU_DELETED_RESOURCES', None)
      if kupu_deleted_resources != None:
        _installKupuDeletedResources(self, out, kupu_deleted_resources)

      # Kupu created resources
      kupu_created_resources = getattr(kupu_module, 'KUPU_CREATED_RESOURCES', None)
      if kupu_created_resources != None:
        _installKupuCreatedResources(self, out, kupu_created_resources)

      # Kupu updated resources
      kupu_updated_resources = getattr(kupu_module, 'KUPU_UPDATED_RESOURCES', None)
      if kupu_updated_resources != None:
        _installKupuUpdatedResources(self, out, kupu_updated_resources)

      out.closeSection("Configs.kupu setup")

    except ImportError:
        out.info("Configs.kupu setup : Noting to be done.")



##---------------------------------------------------------------------------



def kupu_remove(self, out, project_name, globals):
    try:
      kupu_module = __import__("Configs.kupu",
                                globals, locals(),
                                [
                                  'KUPU_CONFIGURATION',
                                  'KUPU_DELETED_LIBRARIES',
                                  'KUPU_CREATED_LIBRARIES',
                                  'KUPU_UPDATED_LIBRARIES',
                                  'KUPU_DELETED_RESOURCES',
                                  'KUPU_CREATED_RESOURCES',
                                  'KUPU_UPDATED_RESOURCES',
                                ]
                              )

      out.openSection("Configs.kupu removal")

      # Kupu configuration
      kupu_configuration = getattr(kupu_module, 'KUPU_CONFIGURATION', None)
      if kupu_configuration != None:
        _removeKupuConfiguration(self, out, kupu_configuration)


      # Kupu deleted libraries
      kupu_deleted_libraries = getattr(kupu_module, 'KUPU_DELETED_LIBRARIES', None)
      if kupu_deleted_libraries != None:
        _removeKupuDeletedLibraries(self, out, kupu_deleted_libraries)

      # Kupu created libraries
      kupu_created_libraries = getattr(kupu_module, 'KUPU_CREATED_LIBRARIES', None)
      if kupu_created_libraries != None:
        _removeKupuCreatedLibraries(self, out, kupu_created_libraries)

      # Kupu updated libraries
      kupu_updated_libraries = getattr(kupu_module, 'KUPU_UPDATED_LIBRARIES', None)
      if kupu_updated_libraries != None:
        _removeKupuUpdatedLibraries(self, out, kupu_updated_libraries)


      # Kupu deleted resources
      kupu_deleted_resources = getattr(kupu_module, 'KUPU_DELETED_RESOURCES', None)
      if kupu_deleted_resources != None:
        _removeKupuDeletedResources(self, out, kupu_deleted_resources)

      # Kupu created resources
      kupu_created_resources = getattr(kupu_module, 'KUPU_CREATED_RESOURCES', None)
      if kupu_created_resources != None:
        _removeKupuCreatedResources(self, out, kupu_created_resources)

      # Kupu updated resources
      kupu_updated_resources = getattr(kupu_module, 'KUPU_UPDATED_RESOURCES', None)
      if kupu_updated_resources != None:
        _removeKupuUpdatedResources(self, out, kupu_updated_resources)

      out.closeSection("Configs.kupu removal")

    except ImportError:
        out.info("Configs.kupu removal : Noting to be done.")



#########################################################################################################
######################################## Install functions ##############################################
#########################################################################################################



## _installKupuConfiguration
# 
# Setup the kupu visual editor.
def _installKupuConfiguration(self, out, kupu_configuration):
    out.openSubsection("Kupu configuration setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            kupu_tool.configure_kupu(**kupu_configuration)
            out.success("Completed kupu configuration setup without errors.")
        except Exception, e:
            out.error("failed kupu configuration setup. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu configuration setup")



##---------------------------------------------------------------------------



## _installKupuDeletedLibraries
# 
# Delete kupu visual editor libraries.
def _installKupuDeletedLibraries(self, out, kupu_deleted_libraries):
    out.openSubsection("Kupu deleted libraries setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            # We compute existing library corresponding indices
            existing_libraries = kupu_tool.zmi_get_libraries()
            kupu_deleted_libraries_indices = [ existing_libraries.index(library) for library in existing_libraries if library['id'] in kupu_deleted_libraries ]
            kupu_tool.deleteLibraries(kupu_deleted_libraries_indices)
            out.success("Completed kupu deleted libraries setup without errors.")
        except Exception, e:
            out.error("failed kupu deleted libraries setup. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu deleted libraries setup")



##---------------------------------------------------------------------------



## _installKupuCreatedLibraries
# 
# Create new kupu visual editor libraries.
def _installKupuCreatedLibraries(self, out, kupu_created_libraries):
    errorFlag = False

    out.openSubsection("Kupu created libraries setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        for kupu_library in kupu_created_libraries:
            try:
                kupu_tool.addLibrary(**kupu_library)
                out.log("Created kupu library named '%s'." % kupu_library.get('id', ''))
            except Exception, e:
                errorFlag = True
                out.error("failed to create kupu library named '%s'. (Error message : %s)" % ( kupu_library.get('id', ''), str(e) ) )

        if not errorFlag:
            out.success("Completed kupu created libraries setup without errors.")

    out.closeSubsection("Kupu created libraries setup")



##---------------------------------------------------------------------------



## _installKupuUpdatedLibraries
# 
# Update kupu visual editor existing libraries.
def _installKupuUpdatedLibraries(self, out, kupu_updated_libraries):
    out.openSubsection("Kupu updated libraries setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            existing_libraries = kupu_tool.zmi_get_libraries()
            for kupu_library in kupu_updated_libraries:
                libraryFound = False
                for existing_library in existing_libraries:
                    if kupu_library.get('id', None) == existing_library['id']:
                        libraryFound = True
                        existing_library['id'] = kupu_library.get('new_id', existing_library['id'])
                        existing_library['title'] = kupu_library.get('title', existing_library['title'])
                        existing_library['uri'] = kupu_library.get('uri', existing_library['uri'])
                        existing_library['src'] = kupu_library.get('src', existing_library['src'])
                        existing_library['icon'] = kupu_library.get('icon', existing_library['icon'])
                if not libraryFound:
                    out.error("Can not update library '%s'. It does not exist." % kupu_library.get('id', None))
            kupu_tool.updateLibraries(existing_libraries)
            out.success("Completed kupu updated libraries setup without errors.")
        except Exception, e:
            out.error("failed kupu updated libraries setup. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu updated libraries setup")



##---------------------------------------------------------------------------



## _installKupuDeletedResources
# 
# Delete kupu visual editor resources.
def _installKupuDeletedResources(self, out, kupu_deleted_resources):
    out.openSubsection("Kupu deleted resources setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            kupu_tool.deleteResourceTypes(kupu_deleted_resources)
            out.success("Completed kupu deleted resources setup without errors.")
        except Exception, e:
            out.error("failed kupu deleted resources setup. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu deleted resources setup")



##---------------------------------------------------------------------------



## _installKupuCreatedResources
# 
# Create new kupu visual editor resources.
def _installKupuCreatedResources(self, out, kupu_created_resources):
    errorFlag = False

    out.openSubsection("Kupu created resources setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        for kupu_resource in kupu_created_resources:
            try:
                kupu_tool.addResourceType(**kupu_resource)
                out.log("Created kupu resource named '%s'." % kupu_resource.get('resource_type', ''))
            except Exception, e:
                errorFlag = True
                out.error("failed to create kupu resource named '%s'. (Error message : %s)" % ( kupu_resource.get('resource_type', ''), str(e) ) )

        if not errorFlag:
            out.success("Completed kupu created resources setup without errors.")

    out.closeSubsection("Kupu created resources setup")



##---------------------------------------------------------------------------



## _installKupuUpdatedResources
# 
# Update kupu visual editor existing resources.
def _installKupuUpdatedResources(self, out, kupu_updated_resources):
    out.openSubsection("Kupu updated resources setup")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            kupu_tool.updateResourceTypes(kupu_updated_resources)
            out.success("Completed kupu updated resources setup without errors.")
        except Exception, e:
            out.error("failed kupu updated resources setup. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu updated resources setup")



#########################################################################################################
######################################### Remove functions ##############################################
#########################################################################################################



## _removeKupuConfiguration
# 
# Remove kupu configuration.
# TODO : Create a remove kupu configuration method.
def _removeKupuConfiguration(self, out, kupu_configuration):
    out.openSubsection("Kupu configuration removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        out.info("Kupu configuration can not be removed.")

    out.closeSubsection("Kupu configuration removal")



##---------------------------------------------------------------------------



## _removeKupuDeletedLibraries
# 
# Remove kupu Deleted libraries.
# TODO : Create a remove kupu deleted libraries method.
def _removeKupuDeletedLibraries(self, out, kupu_deleted_libraries):
    out.openSubsection("Kupu deleted libraries removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        out.info("Kupu deleted libraries can not be removed.")

    out.closeSubsection("Kupu deleted libraries removal")



##---------------------------------------------------------------------------



## _removeKupuCreatedLibraries
# 
# Remove kupu visual editor created libraries.
def _removeKupuCreatedLibraries(self, out, kupu_created_libraries):
    out.openSubsection("Kupu created libraries removal")

    try: # Check for Kupu library tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:

        try:
            # We compute existing library corresponding indices
            kupu_created_libraries_ids = [ kupu_library.get('id', None) for kupu_library in kupu_created_libraries ]

            existing_libraries = kupu_tool.zmi_get_libraries()
            kupu_created_libraries_indices = [ existing_libraries.index(library) for library in existing_libraries if library['id'] in kupu_created_libraries_ids ]
            kupu_tool.deleteLibraries(kupu_created_libraries_indices)
            out.success("Completed kupu created libraries removal without errors.")
        except Exception, e:
            out.error("failed kupu created libraries removal. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu created libraries removal")



##---------------------------------------------------------------------------



## _removeKupuUpdatedLibraries
# 
# Remove kupu updated libraries.
# TODO : Create a remove kupu updated libraries method.
def _removeKupuUpdatedLibraries(self, out, kupu_updated_libraries):
    out.openSubsection("Kupu updated libraries removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        out.info("Kupu updated libraries can not be removed.")

    out.closeSubsection("Kupu updated libraries removal")



##---------------------------------------------------------------------------



## _removeKupuDeletedResources
# 
# Remove kupu Deleted resources.
# TODO : Create a remove kupu deleted resources method.
def _removeKupuDeletedResources(self, out, kupu_deleted_resources):
    out.openSubsection("Kupu deleted resources removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        out.info("Kupu deleted resources can not be removed.")

    out.closeSubsection("Kupu deleted resources removal")



##---------------------------------------------------------------------------



## _removeKupuCreatedResources
# 
# Remove kupu Created resources.
def _removeKupuCreatedResources(self, out, kupu_created_resources):
    out.openSubsection("Kupu created resources removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        try:
            kupu_created_resources_types = [ kupu_resource.get('resource_type', None) for kupu_resource in kupu_created_resources ]
            kupu_tool.deleteResourceTypes(kupu_created_resources_types)
            out.success("Completed kupu created resources removal without errors.")
        except Exception, e:
            out.error("failed kupu created resources removal. (Error message : %s)" % str(e))

    out.closeSubsection("Kupu created resources removal")



##---------------------------------------------------------------------------



## _removeKupuUpdatedResources
# 
# Remove kupu updated resources.
# TODO : Create a remove kupu updated resources method.
def _removeKupuUpdatedResources(self, out, kupu_updated_resources):
    out.openSubsection("Kupu updated resources removal")

    try: # Check for CSS tool existance
        kupu_tool = getToolByName(self, 'kupu_library_tool')
    except AttributeError:
        errorFlag = True
        out.error("'kupu_library_tool' tool not found. 'kupu' product is missing.")
    else:
        out.info("Kupu updated resources can not be removed.")

    out.closeSubsection("Kupu updated resources removal")



#########################################################################################################
######################################### Private functions #############################################
#########################################################################################################

