## File "__init__.py"
## -*- coding: utf-8 -*-

import logging
from config import GLOBALS, PROJECTNAME

from AccessControl import ModuleSecurityInfo
from Products.CMFCore.FSFile import FSFile
from Products.CMFCore.DirectoryView import registerDirectory, registerFileExtension
from Products.CMFCore.utils import ContentInit, ToolInit
from Products.Archetypes.public import process_types, listTypes
from Products.CMFCore.CMFCorePermissions import AddPortalContent

def initialize( context ):

  LOG = logging.getLogger(PROJECTNAME)

  # We check for new file extensions support
  try:
    from Configs.skins import FILE_EXTENSIONS
    for extension in FILE_EXTENSIONS:
      registerFileExtension(extension, FSFile)
  except ImportError, e:
    LOG.info('No file extensions configuration found for this product. (exception : %(error)s)' % { 'error' : str(e), })

  # We check for available skins directories.
  try:
    from Configs.skins import SKIN_DEFINITIONS
    for skin_definition in SKIN_DEFINITIONS:
      try:
        registerDirectory(skin_definition['skin_dir'], GLOBALS)
      except Exception, e:
        LOG.error('Error during skin directory "%(skin_dir)s" registration : %(error)s' % { 'skin_dir' : skin_definition['skin_dir'], 'error' : str(e),})
  except ImportError, e:
    LOG.info('No skins configuration found for this product. (exception : %(error)s)' % { 'error' : str(e), })

  # We register the types of this product.

  try:
    from Configs.types import TYPES_INSTALLED

    for type_name in TYPES_INSTALLED:
      # We import the types to be registered.
      try:
        __import__("content", globals(), locals(), [ type_name, ])
      except ImportError, e:
        LOG.error('Error during import of type "%(type_name)s" : %(error)s' % { 'type_name' : type_name, 'error' : str(e),})

    content_types, constructors, ftis = process_types(
        listTypes(PROJECTNAME),
        PROJECTNAME)

    ContentInit(
        PROJECTNAME + ' Content',
        content_types      = content_types,
        permission         = AddPortalContent,
        extra_constructors = constructors,
        fti                = ftis,
        ).initialize(context)

  except ImportError, e:
    LOG.info('No types configuration found for this product. (exception : %(error)s)' % { 'error' : str(e), })

  # We register the tools of this product.

  try:
    from Configs.tools import TOOLS

    tools = []

    for tool_description in TOOLS:
      # We import the tools to be registered.
      try:
        tool = __import__("Tools.%s" % tool_description['module'], globals(), locals(), [ tool_description['class'], ])
        if getattr(tool, tool_description['class'], None):
          tools.append(getattr(tool, tool_description['class'], None))
      except ImportError, e:
        LOG.error('Error during import of tool "%(tool_class)s" : %(error)s' % { 'tool_class' : tool_description['class'], 'error' : str(e),})

    if tools:

        ToolInit(
              PROJECTNAME + ' Tools', tools=tools,
              ## product_name=PROJECTNAME,
              icon='tool.gif',
            ).initialize(context)


  except ImportError, e:
    LOG.info('No tools configuration found for this product. (exception : %(error)s)' % { 'error' : str(e), })


ModuleSecurityInfo('Products.dcEnhancedHeader').declarePublic('dcEnhancedHeaderMessageFactory')
#
## Import "dcEnhancedHeaderMessageFactory as _" to create message ids
## in the dcenhancedheader domain
## Zope 3.1-style messagefactory module
## BBB: Zope 2.8 / Zope X3.0
try:
    from zope.i18nmessageid import MessageFactory
except ImportError:
    from messagefactory_ import dcEnhancedHeaderMessageFactory
else:
    dcEnhancedHeaderMessageFactory = MessageFactory('dcenhancedheader')


